package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.SysQiyejieshao;

/**
 * qiyejieshaoService接口
 * 
 * @author ruoyi
 * @date 2023-05-16
 */
public interface ISysQiyejieshaoService extends IService<SysQiyejieshao>
{
    /**
     * 查询qiyejieshao
     * 
     * @param id qiyejieshao主键
     * @return qiyejieshao
     */
    public SysQiyejieshao selectSysQiyejieshaoById(Long id);

    /**
     * 查询qiyejieshao列表
     * 
     * @param sysQiyejieshao qiyejieshao
     * @return qiyejieshao集合
     */
    public List<SysQiyejieshao> selectSysQiyejieshaoList(SysQiyejieshao sysQiyejieshao);

    /**
     * 新增qiyejieshao
     * 
     * @param sysQiyejieshao qiyejieshao
     * @return 结果
     */
    public int insertSysQiyejieshao(SysQiyejieshao sysQiyejieshao);

    /**
     * 修改qiyejieshao
     * 
     * @param sysQiyejieshao qiyejieshao
     * @return 结果
     */
    public int updateSysQiyejieshao(SysQiyejieshao sysQiyejieshao);

    /**
     * 批量删除qiyejieshao
     * 
     * @param ids 需要删除的qiyejieshao主键集合
     * @return 结果
     */
    public int deleteSysQiyejieshaoByIds(Long[] ids);

    /**
     * 删除qiyejieshao信息
     * 
     * @param id qiyejieshao主键
     * @return 结果
     */
    public int deleteSysQiyejieshaoById(Long id);
}
